@@ -5,7 +5,16 @@ import sys
 import os
 import optparse
 import shutil
-import subprocess
+try:
+    import subprocess
+except ImportError, e:
+    if sys.version_info <= (2, 3):
+        print 'ERROR: %s' % e
+        print 'ERROR: this script requires Python 2.4 or greater; or at least the subprocess module.'
+        sys.exit(101)
+    else:
+        raise
+    
 join = os.path.join
 py_version = 'python%s.%s' % (sys.version_info[0], sys.version_info[1])
 
@@ -179,6 +188,11 @@ def main():
 
     home_dir = args[0]
 
+    if os.environ.get('WORKING_ENV'):
+        logger.fatal('ERROR: you cannot run virtualenv while in a workingenv')
+        logger.fatal('Please deactivate your workingenv, then re-run this script')
+        sys.exit(3)
+
     create_environment(home_dir, site_packages=not options.no_site_packages, clear=options.clear)
     if 'after_install' in globals():
         after_install(options, home_dir)
@@ -216,8 +230,13 @@ def create_environment(home_dir, site_packages=True, clear=False):
     mkdir(join(lib_dir, 'site-packages'))
     writefile(join(lib_dir, 'site.py'), SITE_PY)
     writefile(join(lib_dir, 'orig-prefix.txt'), prefix)
+    site_packages_filename = join(lib_dir, 'no-global-site-packages.txt')
     if not site_packages:
-        writefile(join(stdlib_dir, 'no-global-site-packages.txt'), '')
+        writefile(site_packages_filename, '')
+    else:
+        if os.path.exists(site_packages_filename):
+            logger.info('Deleting %s' % site_packages_filename)
+            os.unlink(site_packages_filename)
 
     #mkdir(inc_dir)
     #stdinc_dir = join(prefix, 'include', py_version)
@@ -236,10 +255,27 @@ def create_environment(home_dir, site_packages=True, clear=False):
         ## FIXME: could I just hard link?
         shutil.copyfile(sys.executable, py_executable)
         make_exe(py_executable)
+    cmd = [py_executable, '-c', 'import sys; print sys.prefix']
+    logger.info('Testing executable with %s %s "%s"' % tuple(cmd))
+    proc = subprocess.Popen(cmd,
+                            stdout=subprocess.PIPE)
+    proc_stdout, proc_stderr = proc.communicate()
+    proc_stdout = os.path.abspath(proc_stdout.strip())
+    if proc_stdout != os.path.abspath(home_dir):
+        logger.fatal(
+            'ERROR: The executable %s is not functioning' % py_executable)
+        logger.fatal(
+            'ERROR: It thinks sys.prefix is %r (should be %r)'
+            % (proc_stdout, home_dir))
+        logger.fatal(
+            'ERROR: virtualenv is not compatible with this system or executable')
+        sys.exit(100)
+    else:
+        logger.info('Got sys.prefix result: %r' % proc_stdout)
 
     pydistutils = os.path.expanduser('~/.pydistutils.cfg')
     if os.path.exists(pydistutils):
-        logger.notify('Please make sure you remove any previous custom paths from'
+        logger.notify('Please make sure you remove any previous custom paths from '
                       'your %s file.' % pydistutils)
 
     install_setuptools(py_executable)
